We want, as much as possible, to focus on one tool solving one problem, with as many tools as possible to cover our surface. Also, we strive to keep our tools self-hosted for reasons in our [design principles](./Policies/Design Principles.md). These lists are not 100% comprehensive -- generic, common parts like Ethernet cables or system libraries aren't listed as they're easily replaced by competent staff.

See our design principles for our selected development languages as well.

# Self-written solutions
_NOTE_: These solutions are chosen very, very carefully. We write them either for educational reasons or because they fill a very specific role unique to the AniNIX. All of these are candidates to be replaced with upstream tools.

| Problem               | Tool                                                |
| --------------------- | --------------------------------------------------- |
| Backups               | [AniNIX/Aether](/AniNIX/Aether)                     |
| CI/CD Pipeline        | [AniNIX/Maat](/AniNIX/Maat)                         |
| Cryptography          | [AniNIX/CryptoWorkbench](/AniNIX/CryptoWorkbench)   |
| IRCbot                | [AniNIX/TheRaven](/AniNIX/TheRaven)                 |
| Language reference    | [AniNIX/HelloWorld](/AniNIX/HelloWorld)             |
| Secure code standards | [AniNIX/Inquisitorius](/AniNIX/Inquisitorius)       |
| Standard functions    | [AniNIX/Uniglot](/AniNIX/Uniglot)                   |
| Web crawler           | [AniNIX/WolfPack](/AniNIX/WolfPack)                 |

# On-site Hardware
| Problem               | Tool                   | Provider Reference         |
| --------------------- | ---------------------- | -------------------------- |
| Server                | Supermicro X-series    | https://unixsurplus.com    |
| Automation Node       | Raspberry Pi           | https://raspberrypi.org    |
| Smartphone            | LG G8                  | https://www.lg.com/us      |
| Router                | Netgear R7000          | https://www.netgear.com    |
| Personal hardware     | HP Omen                | https://www.omen.com/      | 
| UPS                   | CyberPower             | https://cyberpowersystems.com/ |
| Keyboards             | Corsair K70            | https://www.corsair.com/   |
| NVR Cameras           | OOSSXX                 | http://oossxx.com/         |
| HVAC w/ alarms        | Nest Thermostat/Protect| https://store.google.com   | 
| Remote access         | Chamberlain MyQ        | https://www.chamberlain.com/ |
| Housekeeping          | iRobot Roomba and Brava| http://irobot.com/         |
| Paper handling        | Brother printing       | http://brother.com/        |

# Self-hosted solutions

## Platforms
| Problem               | Tool                   | Provider Reference         |
| --------------------- | ---------------------- | -------------------------- |
| Main OS               | [AniNIX/ShadowArch](/AniNIX/ShadowArch) | http://archlinux.org/ |
| Embedded OS           | Raspbian               |https://www.raspberrypi.org/| 
| Mobile OS             | Android                | https://www.android.com/   |
| Read-only access      | [AniNIX/WebServer](/AniNIX/Ubiqtorate/src/branch/main/roles/WebServer) | http://openresty.org/en/ |
| Read-write access     | [SSH](/AniNIX/Ubiqtorate/src/branch/main/roles/SSH) | https://www.openssh.com |
| Network configuration | Netctl                 | https://wiki.archlinux.org/index.php/netctl |
| Service management    | systemd                | https://wiki.archlinux.org/index.php/systemd |
| Terminal management   | tmux                   | https://tmux.github.io/    |
| Window management     | XFCE4                  | http://www.xfce.org        |
| Office suite          | LibreOffice            | https://www.libreoffice.org|
| Browser               | Google Chrome          | https://www.google.com/chrome/ |
| News tracking         | [AniNIX/Singularity](/AniNIX/Ubiqtorate/src/branch/main/roles/Singularity) | https://tt-rss.org/ |
| Media CDN             | [AniNIX/Yggdrasil](/AniNIX/Ubiqtorate/src/branch/main/roles/Yggdrasil) | https://emby.media/ |

## DevOps
| Problem               | Tool                   | Provider Reference         |
| --------------------- | ---------------------- | -------------------------- |
| Work tracking         | [AniNIX/Foundation](/AniNIX/Ubiqtorate/src/branch/main/roles/Foundation) | https://gitea.io/ |
| Revision control      | Git                    | https://git-scm.com/       |
| Documentation         | [This Wiki](/AniNIX/Wiki) | https://daringfireball.net/projects/markdown/ |
| Infra-as-Code         | [AniNIX/Ubiqtorate](/AniNIX/Ubiqtorate) | https://docs.ansible.com/ |
| Hypervisor            | [AniNIX/MaatHypervisor](/AniNIX/Ubiqtorate/src/branch/main/roles/MaatHypervisor) | https://wiki.qemu.org/ |
| Network lookup        | [AniNIX/Nazara](/AniNIX/Ubiqtorate/src/branch/main/roles/Nazara) | https://pi-hole.net |
| Routing management    | [AniNIX/Shadowfeed](/AniNIX/Ubiqtorate/src/branch/main/roles/Shadowfeed) | https://dd-wrt.com/ |
| Communication         | [AniNIX/IRC](/AniNIX/Ubiqtorate/src/branch/main/roles/IRC) | https://www.anope.org/, 

## Security
In the AAA model, authorization is delegated to each individual application consuming the authentication and auditing. 

| Problem               | Tool                   | Provider Reference         |
| --------------------- | ---------------------- | -------------------------- |
| Penetration testing   | Kali Linux             | https://www.kali.org/      |
| Vulnerability scanning| OpenVAS                | https://www.openvas.org/   |
| SIEM                  | [AniNIX/Sharingan](/AniNIX/Ubiqtorate/src/branch/main/roles/Sharingan) | https://www.graylog.org/ |
| Authentication        | [AniNIX/Sora](/AniNIX/Ubiqtorate/src/branch/main/roles/Sora) | https://www.openldap.org/ |
| Auditing              | syslog-ng              | https://www.syslog-ng.com/ |
| Identity verification | GPG                    | https://www.gnupg.org/     |
| VPN                   | Nord                   | http://nordvpn.com/        |
| Network encryption    | [SSL](/AniNIX/Ubiqtorate/src/branch/main/roles/SSL) | https://letsencrypt.org/ |
| Network IPS           | sshguard               | https://www.sshguard.net/  |
| Network IDS           | suricata               | http://suricata-ids.org/   |
| OSINT                 | oinkmaster             | http://oinkmaster.sourceforge.net/ |
| Host IDS              | clamav                 | https://www.clamav.net/    | 
| Disk encryption       | LUKS-on-LVM            | https://gitlab.com/cryptsetup/cryptsetup/ |
| Warrant protection    | [AniNIX/WarrantCanary](/AniNIX/WarrantCanary) | 
| Physical security     | [AniNIX Martial Arts](/martialarts) | https://ushapkidofederation.files.wordpress.com/ |

# Purchased / Managed Solutions
| Problem               | Tool                   | Provider Reference         |
| --------------------- | ---------------------- | -------------------------- |
| Backup communications | Discord                | https://discordapp.com     | 
| Power                 | Alliant Energy         | https://www.alliantenergy.com/ |
| Internet              | Charter ISP            | https://www.spectrum.com/  | 
| Backup Internet       | US Cellular            | http://uscellular.com/     |
| Code publishing       | GitHub                 | https://github.com/        |
| Cloud office suite    | Google Suite           | https://workspace.google.com/ |
| Payment               | Stripe                 | https://stripe.com/        |
| Banking               | Chase                  | https://www.chase.com/     |
| Workout options       | DAREBEE                | https://darebee.com        |
| Team-building         | [Imperial Intelligence](/swtor/Imperial_Intelligence) | http://swtor.com/ |
